/*
 *  RapidMiner
 *
 *  Copyright (C) 2001-2015 by RapidMiner GmbH and the contributors
 *
 *  Complete list of developers available at our web site:
 *
 *       http://rapidminer.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package cl;


/**
 * Simple parameter container for the string coordinate. Variable names similar to paper.
 * 
 * @author Christian Leitold
 */
public class StringCoordinateModelParameters {
	
	private int mStringPoints;
	
	private int mStringDimension;
	
	private int fixedIndex;
	
	private double[][] stringCoords;
	
	private CubicSpline fAlphaSpline;
	
	private double[] scalingFactors;
	
	private double finalScore;
	
	public StringCoordinateModelParameters(int mStringPoints, int mStringDimension, int fixedIndex, double[][] stringCoords, CubicSpline fAlphaSpline, double[] scalingFactors) {
		this(mStringPoints, mStringDimension, fixedIndex, stringCoords, fAlphaSpline,  scalingFactors, -1.0);
	}
	
	public StringCoordinateModelParameters(int mStringPoints, int mStringDimension, int fixedIndex, double[][] stringCoords, CubicSpline fAlphaSpline, double[] scalingFactors, double finalScore) {
		this.mStringPoints = mStringPoints;
		this.mStringDimension = mStringDimension;
		this.fixedIndex = fixedIndex;
		this.stringCoords = stringCoords;
		this.fAlphaSpline = fAlphaSpline;
		this.scalingFactors = scalingFactors;
		this.finalScore = finalScore;
	}
	
	public int getMStringPoints() {
		return this.mStringPoints;
	}
	
	public int getMStringDimension() {
		return this.mStringDimension;
	}
	
	public int getFixedIndex() {
		return this.fixedIndex;
	}
	
	public double[][] getStringCoords() {
		return this.stringCoords;
	}

	public CubicSpline getFAlphaSpline() {
		return this.fAlphaSpline;
	}
	
	public double[] getScalingFactors() {
		return this.scalingFactors;
	}
	
	public void setFinalScore(double finalScore) {
		this.finalScore = finalScore;
	}
	
	public double getFinalScore() {
		return this.finalScore;
	}
	
}
