/**
 * 
 */
package cl;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Shape;
import java.awt.geom.Rectangle2D;

import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.DatasetRenderingOrder;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.xy.XYItemRenderer;
import org.jfree.chart.renderer.xy.XYLineAndShapeRenderer;
import org.jfree.data.xy.DefaultXYZDataset;

import com.rapidminer.datatable.DataTable;
import com.rapidminer.datatable.DataTableRow;
import com.rapidminer.gui.plotter.PlotterConfigurationModel;
import com.rapidminer.gui.plotter.charts.AbstractChartPanel;
import com.rapidminer.gui.plotter.charts.ScatterPlotter2;
import com.rapidminer.tools.Tools;


/**
 * @author Christian Leitold
 * This plotter can make use of additional visualization data for the string
 * coordinate. The "string" is plotted as a sequence of points connected by
 * straight line segments.
 *
 */
public class StringCoordinateScatterPlotter extends ScatterPlotter2 {
	
	/**
	 * 
	 */
	private static final long serialVersionUID = -3226204735603876151L;

	/**
	 * @param settings
	 */
	public StringCoordinateScatterPlotter(PlotterConfigurationModel settings) {
		super(settings);
	}

	/**
	 * @param settings
	 * @param dataTable
	 */
	public StringCoordinateScatterPlotter(PlotterConfigurationModel settings, DataTable dataTable) {
		super(settings, dataTable);
	}
	
	private DefaultXYZDataset stringImagedataSet;
	
	private boolean plotColumnsLogScale = false;
	
	/** Sets if the given axis should be plotted with log scale. Has to be done again here since variable is private. */
	@Override
	public void setLogScaleForPlotColumns(boolean logScale) {
		super.setLogScaleForPlotColumns(logScale);
		plotColumnsLogScale = logScale;
		updatePlotter();
	}
	
	@Override
	public void updatePlotter() {
		
		super.updatePlotter();
		
		// first, get the chart so we can add the string
		AbstractChartPanel panel = getPlotterPanel();
		JFreeChart chart = panel.getChart();
		XYPlot plot = chart.getXYPlot();
		
		// now we need to check if the additional data is present in the dataTable
		// String name = dataTable.getName();
		// int columns = dataTable.getNumberOfColumns();
		String[] names = dataTable.getColumnNames();
		// System.out.format("DataTable \"%s\" has %d columns.\n", name, columns);
		int plotColumn = -1;
		int stringImageIndex = -1;
		// System.out.format("StringCoordinateScatterPlotter:");
		for (int i=0;i<names.length;i++) {
			// System.out.format(" %d = %s", i, names[i]);
			if (getPlotColumn(i)) plotColumn = i;
			if (names[i].equals("string_image")) stringImageIndex = i;
			/* if (i < names.length-1) {
				System.out.format(",");
			} */
		}
		// System.out.format(Tools.getLineSeparator());
		int indexX = getAxis(0);
		int indexY = getAxis(1);
		// System.out.format("The used axis are %d = %s for x, %d = %s for y, and %d = %s for color.\n", indexX, names[indexX], indexY, names[indexY], plotColumn, names[plotColumn]);
		// System.out.format("The index used to indicate string images is %d.\n", stringImageIndex);
		
		stringImagedataSet = new DefaultXYZDataset();
		
		// now get the actual values
		List<double[]> dataList = new LinkedList<double[]>();
		
		synchronized (dataTable) {
			Iterator<DataTableRow> i = this.dataTable.iterator();
			while (i.hasNext()) {
				DataTableRow row = i.next();

				if (stringImageIndex >= 0) {
					
					double stringImage = row.getValue(stringImageIndex);
					
					if (Tools.isNotEqual(stringImage, Double.NaN)) {
						if (stringImage == 0.0d) {
							
							double xValue = Double.NaN;
							if (indexX >= 0) {
								xValue = row.getValue(indexX);
							}

							double yValue = Double.NaN;
							if (indexY >= 0) {
								yValue = row.getValue(indexY);
							}

							double colorValue = Double.NaN;
							if (plotColumn >= 0) {
								colorValue = row.getValue(plotColumn);
							}

							if (plotColumnsLogScale) {
								if (Tools.isLessEqual(colorValue, 0.0d)) {
									colorValue = 0;
								} else {
									colorValue = Math.log10(colorValue);
								}
							}
							
							double[] data = new double[3];
							data[0] = xValue;
							data[1] = yValue;
							data[2] = colorValue;

							dataList.add(data);
							
						}
					}
					
				}
				
			}	
		}
		
		double[][] data = new double[3][dataList.size()];
		
		int counter = 0;
		for (double[] dataItem : dataList) {
			for (int i=0;i<3;i++) {
				data[i][counter] = dataItem[i];
			}
			counter++;
		}
		
		// add data to existing plot, change order to "normal" so that newer stuff is above older stuff
		stringImagedataSet.addSeries("stringImages", data);
		plot.setDataset(1, stringImagedataSet);
		XYItemRenderer renderer = new XYLineAndShapeRenderer();		
		plot.setDatasetRenderingOrder(DatasetRenderingOrder.FORWARD);
		renderer.setSeriesPaint(0, Color.BLACK); 
		BasicStroke stroke = new BasicStroke(3.0f);
		renderer.setSeriesStroke(0, stroke);
		Shape shape = new Rectangle2D.Float(-5.0f, -5.0f, 10.0f, 10.0f);
		renderer.setSeriesShape(0, shape);
		plot.setRenderer(1, renderer);
		
	}

}
